@@ -183,6 +183,36 @@ class BosClient(BceBaseClient):
                            params={b'acl': b''},
                            config=config)
 
+    @required(bucket_name=(bytes, str))
+    def set_bucket_storage_class(self, bucket_name, storage_class=None, config=None):
+        """
+
+        :param bucket_name:
+        :param config:
+        :return:
+        """
+        return self._send_request(http_methods.PUT,
+                           bucket_name,
+                           body=json.dumps({'storageClass': storage_class},
+                                           default=BosClient._dump_acl_object),
+                           headers={http_headers.CONTENT_TYPE: http_content_types.JSON},
+                           params={b'storageClass': b''},
+                           config=config)
+
+
+    @required(bucket_name=(bytes, str))
+    def get_bucket_storage_class(self, bucket_name, config=None):
+        """
+
+        :param bucket_name:
+        :param config:
+        :return:
+        """
+        return self._send_request(http_methods.GET,
+                           bucket_name,
+                           params={b'storageClass': b''},
+                           config=config)
+
     @required(bucket_name=(bytes, str))
     def delete_bucket(self, bucket_name, config=None):
         """
@@ -787,6 +817,31 @@ class BosClient(BceBaseClient):
             headers=BosClient._get_range_header_dict(range),
             config=config,
             body_parser=BosClient._parse_bos_object)
+# restore object
+    @required(bucket_name=(bytes, str), key=(bytes, str))
+    def restore_object(self, bucket_name, key, days=None, tier="Standard", config=None):
+        """
+
+        :param bucket_name:
+        :param key:
+        :param config:
+        :return:
+        """
+        key = compat.convert_to_bytes(key)
+        headers = {}
+        if days is not None:
+            headers[http_headers.BOS_RESTORE_DAYS] = days
+        if tier not in ("Standard", "Expedited"):
+            raise ValueError('valid tier:%s for restore_object.The valid value is \"Standard\" and \"Expedited\"' )
+        headers[http_headers.BOS_RESTORE_TIER] = tier
+        return self._send_request(
+            http_methods.POST,
+            bucket_name,
+            key,
+            headers=headers,
+            params={b'restore': b''},
+            config=config,
+            body_parser=BosClient._parse_bos_object)
 
     @staticmethod
     def _save_body_to_file(http_response, response, file_name, buf_size):
